# frozen_string_literal: true

class Credentials
  CREDENTIALS_FILE = 'credentials.json'.freeze

  def self.for(dir:, credentials_type:)
    puts "Loading #{credentials_type} credentials for environment #{environment} from '#{credentials_file(dir)}'..."
    load(dir)[environment][credentials_type]
  end

  def self.credentials_file(dir)
    File.join(dir, '..', 'etc', CREDENTIALS_FILE)
  end
  private_class_method :credentials_file

  def self.environment
    ENV['ENV'] || 'development'
  end
  private_class_method :environment

  def self.load(dir)
    JSON.parse(`ejson decrypt #{credentials_file(dir)}`)
  end
  private_class_method :load
end
