#!/bin/false

require 'logger'
require 'colorize'
require 'recursive_open_struct'

class MqttSrvcLogger
  def initialize(dir)
    config = Config.for(dir: dir, config_type: 'logger')['loggers']

    @loggers = {}
    @logger_formatter = proc do |severity, datetime, _progname, msg|
      "%s %-6s %s\n" % [datetime, severity, msg]
    end

    config.each do |logger_config|
      logger_config = RecursiveOpenStruct.new(logger_config)

      @loggers[logger_config.path] = configured_logger(logger_config)
    end
  end

  def debug(msg)
    each_logger { |logger| logger.debug(msg.light_blue) }
  end

  def info(msg)
    each_logger { |logger| logger.info(msg.green) }
  end

  def data(msg)
    each_logger { |logger| logger.info(msg.magenta) }
  end

  def warn(msg)
    each_logger { |logger| logger.warn(msg.yellow) }
  end

  def error(msg)
    each_logger { |logger| logger.error(msg.red) }
  end

  def error_bold(msg)
    each_logger { |logger| logger.error(msg.red.bold) }
  end

  alias fatal error_bold

  private

  def each_logger
    @loggers.each do |_key, logger|
      yield logger
    end
  end

  def configured_logger(logger_config)
    if logger_config.path == 'STDOUT'
      STDOUT.sync = true
      logger = Logger.new(STDOUT)
    else
      create_log_dir(File.dirname(logger_config.path))

      logger = Logger.new(
        logger_config.path,
        logger_config.count,
        logger_config.size
      )
    end

    logger.level = logger_config.level if logger_config.level
    logger.formatter = @logger_formatter

    logger
  end

  def create_log_dir(dir)
    Dir.mkdir(dir) unless Dir.exist?(dir)
  end
end
